==> gazie7.30.zip: gazie/modules/inform/menu.italian.php <==
<?php

/*
  --------------------------------------------------------------------------
  GAzie - Gestione Azienda
  Copyright (C) 2004-2020 - Antonio De Vincentiis Montesilvano (PE)
  (http://www.devincentiis.it)
  <http://gazie.sourceforge.net>
  --------------------------------------------------------------------------
  Questo programma e` free software;   e` lecito redistribuirlo  e/o
  modificarlo secondo i  termini della Licenza Pubblica Generica GNU
  come e` pubblicata dalla Free Software Foundation; o la versione 2
  della licenza o (a propria scelta) una versione successiva.

  Questo programma  e` distribuito nella speranza  che sia utile, ma
  SENZA   ALCUNA GARANZIA; senza  neppure  la  garanzia implicita di
  NEGOZIABILITA` o di  APPLICABILITA` PER UN  PARTICOLARE SCOPO.  Si
  veda la Licenza Pubblica Generica GNU per avere maggiori dettagli.

  Ognuno dovrebbe avere   ricevuto una copia  della Licenza Pubblica
  Generica GNU insieme a   questo programma; in caso  contrario,  si
  scriva   alla   Free  Software Foundation, 51 Franklin Street,
  Fifth Floor Boston, MA 02110-1335 USA Stati Uniti.
  --------------------------------------------------------------------------
 */
$transl['inform'] = array('name' => "Tools & Info",
    'title' => "Utilit&agrave; ed informazioni",
    'm2' => array(1 => array("Selezione e stampa lettera", "Lettere"),
        2 => array("Selezione e stampa carta intestata", "Carta Intestata"),
        3 => array("Lista dei salvataggi su server", "Backups"),
        4 => array("Controllo nuova versione", "Aggiornamento"),
        5 => array("Aggiorna Sito Web", "Crea/aggiorna sito web"),
        6 => array("Rubrica Indirizzi", "Siti Aziendali"),
        7 => array("Anagrafiche comuni a tutte le aziende", "Anagrafiche comuni")
    ),
    'm3' => array(1 => array("Controllo sbilancio dare-avere dei movimenti contabili", "Controllo sbilancio movimenti contabili"),
        2 => array("Controllo numerazione protocolli IVA", "Controllo numerazione protocolli IVA"),
        3 => array("Scrivi una nuova lettera", "Scrivi nuova lettera"),
        4 => array("Gestione indirizzi internet", "Gestione Siti"),
        5 => array("Aggiungi indirizzo", "Aggiungi Sito"),
        6 => array("Aggiorna OpenCart", "Aggiorna OpenCart"),
        7 => array("Aggiorna sito web", "Crea/aggiorna sito Statico"),
        8 => array("Backup su browser", "Backup remoto"),
        9 => array("Backup su server","Backup locale"),
        10 => array("Anagrafiche clienti-fornitori", "Anagrafiche clienti-fornitori"),
        11 => array("Comuni","Municipalità"),
        12 => array("Province","Province")
    )
);
?>

==> gazie8.00.zip: gazie/modules/inform/menu.italian.php <==
<?php

/*
  --------------------------------------------------------------------------
  GAzie - Gestione Azienda
  Copyright (C) 2004-2021 - Antonio De Vincentiis Montesilvano (PE)
  (http://www.devincentiis.it)
  <http://gazie.sourceforge.net>
  --------------------------------------------------------------------------
  Questo programma e` free software;   e` lecito redistribuirlo  e/o
  modificarlo secondo i  termini della Licenza Pubblica Generica GNU
  come e` pubblicata dalla Free Software Foundation; o la versione 2
  della licenza o (a propria scelta) una versione successiva.

  Questo programma  e` distribuito nella speranza  che sia utile, ma
  SENZA   ALCUNA GARANZIA; senza  neppure  la  garanzia implicita di
  NEGOZIABILITA` o di  APPLICABILITA` PER UN  PARTICOLARE SCOPO.  Si
  veda la Licenza Pubblica Generica GNU per avere maggiori dettagli.

  Ognuno dovrebbe avere   ricevuto una copia  della Licenza Pubblica
  Generica GNU insieme a   questo programma; in caso  contrario,  si
  scriva   alla   Free  Software Foundation, 51 Franklin Street,
  Fifth Floor Boston, MA 02110-1335 USA Stati Uniti.
  --------------------------------------------------------------------------
 */
$transl['inform'] = array('name' => "Tools & Info",
    'title' => "Utilit&agrave; ed informazioni",
    'm2' => array(1 => array("Selezione e stampa lettera", "Lettere"),
        2 => array("Selezione e stampa carta intestata", "Carta Intestata"),
        3 => array("Lista dei salvataggi su server", "Backups"),
        4 => array("Controllo nuova versione", "Aggiornamento"),
        5 => array("Aggiorna Sito Web", "Crea/aggiorna sito web"),
        6 => array("Rubrica Indirizzi", "Siti Aziendali"),
        7 => array("Anagrafiche comuni a tutte le aziende", "Anagrafiche comuni"),
        8 => array("Ricostruzione scadenzario", "Ricostruzione scadenzario")
    ),
    'm3' => array(1 => array("Controllo sbilancio dare-avere dei movimenti contabili", "Controllo sbilancio movimenti contabili"),
        2 => array("Controllo numerazione protocolli IVA", "Controllo numerazione protocolli IVA"),
        3 => array("Scrivi una nuova lettera", "Scrivi nuova lettera"),
        4 => array("Gestione indirizzi internet", "Gestione Siti"),
        5 => array("Aggiungi indirizzo", "Aggiungi Sito"),
        6 => array("Aggiorna OpenCart", "Aggiorna OpenCart"),
        7 => array("Aggiorna sito web", "Crea/aggiorna sito Statico"),
        8 => array("Backup su browser", "Backup remoto"),
        9 => array("Backup su server","Backup locale"),
        10 => array("Anagrafiche clienti-fornitori", "Anagrafiche clienti-fornitori"),
        11 => array("Comuni","Municipalità"),
        12 => array("Province","Province"),
        13 => array("Banche","Sportelli bancari")
    )
);
?>
